require 'spec_helper'

RSpec.describe LimeLightPlatform, "#order_find" do
  context "Lime Light Platform - Membership API - order_find" do
    it "Finds an order based upon criteria" do
      lime_light = LimeLightPlatform.new(
        ENV['APP_KEY'],
        ENV['API_USERNAME'],
        ENV['API_PASSWORD'],
        ENV['DEV_SUB'],
        false
      )
      status_options = [
        ENV['TEST_ORDER_FIND_ALL'],
        ENV['TEST_ORDER_FIND_DECLINES'],
        ENV['TEST_ORDER_FIND_SUCCESS'],
        ENV['TEST_ORDER_FIND_NEW'],
        ENV['TEST_ORDER_FIND_APPROVED'],
        ENV['TEST_ORDER_FIND_PENDING'],
        ENV['TEST_ORDER_FIND_HOLD'],
        ENV['TEST_ORDER_FIND_RECURRING'],
        ENV['TEST_ORDER_FIND_FRAUD'],
        ENV['TEST_ORDER_FIND_ARCHIVED'],
        ENV['TEST_ORDER_FIND_CHARGEBACK'],
        ENV['TEST_ORDER_FIND_VOID'],
        ENV['TEST_ORDER_FIND_UNSHIPPED'],
        ENV['TEST_ORDER_FIND_SHIPPED'],
        ENV['TEST_ORDER_FIND_CONFIRMED'],
        ENV['TEST_ORDER_FIND_NOT_CONFIRMED'],
        ENV['TEST_ORDER_FIND_NO_CONFIRMATION_STATUS'],
        ENV['TEST_ORDER_FIND_NO_UPSELLS'],
        ENV['TEST_ORDER_FIND_HAS_UPSELLS'],
        ENV['TEST_ORDER_FIND_FULL_REFUNDS'],
        ENV['TEST_ORDER_FIND_PARTIAL_REFUNDS'],
        ENV['TEST_ORDER_FIND_NO_PRESERVE_GATEWAY'],
        ENV['TEST_ORDER_FIND_ALL_REFUNDS']
      ]
      criteria_options = [
        {'customer_id' => ENV['TEST_ORDER_FIND_CRITERIA_CUSTOMER_ID']},
        {'category_id' => ENV['TEST_ORDER_FIND_CRITERIA_CUSTOMER_ID']},
        {'customer_id' => ENV['TEST_ORDER_FIND_CRITERIA_CUSTOMER_ID']},
        {'category_id' => ENV['TEST_ORDER_FIND_CRITERIA_CATEGORY_ID']},
        {'first_6_cc' => ENV['TEST_ORDER_FIND_CRITERIA_FIRST_6_CC']},
        {'last_4_cc' => ENV['TEST_ORDER_FIND_CRITERIA_LAST_4_CC']},
        {'order_total' => ENV['TEST_ORDER_FIND_CRITERIA_ORDER_TOTAL']},
        {'first_name' => ENV['TEST_ORDER_FIND_CRITERIA_FIRST_NAME']},
        {'last_name' => ENV['TEST_ORDER_FIND_CRITERIA_LAST_NAME']},
        {'billing_first_name' => ENV['TEST_ORDER_FIND_CRITERIA_BILLING_FIRST_NAME']},
        {'billing_last_name' => ENV['TEST_ORDER_FIND_CRITERIA_BILLING_LAST_NAME']},
        {'shipping_first_name' => ENV['TEST_ORDER_FIND_CRITERIA_SHIPPING_FIRST_NAME']},
        {'shipping_last_name' => ENV['TEST_ORDER_FIND_CRITERIA_SHIPPING_LAST_NAME']},
        {'address' => ENV['TEST_ORDER_FIND_ADDRESS']},
        {'city' => ENV['TEST_ORDER_FIND_CITY']},
        {'state' => ENV['TEST_ORDER_FIND_STATE']},
        {'zip' => ENV['TEST_ORDER_FIND_ZIP']},
        {'country' => ENV['TEST_ORDER_FIND_COUNTRY']},
        {'phone' => ENV['TEST_ORDER_FIND_PHONE']},
        {'email' => ENV['TEST_ORDER_FIND_EMAIL']},
        {'ip_address' => ENV['TEST_ORDER_FIND_IP_ADDRESS']},
        {'transaction_id' => ENV['TEST_ORDER_FIND_TRANSACTION_ID']},
        {'affiliate_id' => ENV['TEST_ORDER_FIND_AFFILIATE_ID']},
        {'sub_affiliate_id' => ENV['TEST_ORDER_FIND_SUB_AFFILIATE_ID']},
        {'billing_cycle' => ENV['TEST_ORDER_FIND_BILLING_CYCLE']},
        {'tracking_num' => ENV['TEST_ORDER_FIND_TRACKING_NUM']},
        {'last_4_routing' => ENV['TEST_ORDER_FIND_LAST_4_ROUTING']},
        {'last_4_account' => ENV['TEST_ORDER_FIND_LAST_4_ACCOUNT']},
        {'last_4_ssn' => ENV['TEST_ORDER_FIND_LAST_4_SSN']},
        {'order_total' => {"range" => ['50.00', '100.00']}},
        {'status' => status_options.sample}
      ]
      response = lime_light.order_find({
        'campaign_id' => ENV['TEST_ORDER_FIND_CAMPAIGN_ID'],
        'start_date' => ENV['TEST_ORDER_FIND_START_DATE'],
        'end_date' => ENV['TEST_ORDER_FIND_END_DATE'],
        'start_time' => ENV['TEST_ORDER_FIND_START_TIME'],
        'end_time' => ENV['TEST_ORDER_FIND_END_TIME'],
        'search_type' => ENV['TEST_ORDER_FIND_SEARCH_TYPE'],
        'criteria' => criteria_options.sample
      })
      expect(response[:success]).to eq true
    end
  end
end