require 'spec_helper'
require 'faker'
Faker::Config.locale = 'en-US'

RSpec.describe LimeLightPlatform, "#order_update" do
  context "Lime Light Platform - Membership API - order_update" do
    it "Updates an order based upon criteria" do
      lime_light = LimeLightPlatform.new(
        ENV['APP_KEY'],
        ENV['API_USERNAME'],
        ENV['API_PASSWORD'],
        ENV['DEV_SUB'],
        false
      )
      options = [
        {
          'confirmation_status' => ENV['TEST_ORDER_UPDATE_CONFIRMATION_STATUS'],
          'blacklist' => ENV['TEST_ORDER_UPDATE_BLACKLIST'],
          'fraud' => ENV['TEST_ORDER_UPDATE_FRAUD'],
          'chargeback' => ENV['TEST_ORDER_UPDATE_CHARGEBACK']
        },
        {
          'notes' => Faker::RickAndMorty.quote,
          'first_name' => Faker::Name.first_name,
          'last_name' => Faker::Name.last_name,
          'email' => Faker::Internet.email
        },
        {
          'phone' => Faker::PhoneNumber.phone_number
        },
        {
          'shipping_method' => ENV['TEST_ORDER_UPDATE_SHIPPING_METHOD'],
          'shipping_address1' => Faker::Address.street_address,
          'shipping_address2' => Faker::Address.secondary_address
        },
        {
          'shipping_city' => Faker::Address.city,
          'shipping_zip' => Faker::Address.postcode,
          'shipping_state' => Faker::Address.state_abbr,
          'shipping_country' => ENV['TEST_ORDER_UPDATE_SHIPPING_COUNTRY']
        },
        {
          'billing_address1' => Faker::Address.street_address,
          'billing_address2' => Faker::Address.secondary_address,
          'billing_city' => Faker::Address.city
        },
        {
          'billing_zip' => Faker::Address.postcode,
          'billing_state' => Faker::Address.state_abbr,
          'billing_country' => ENV['TEST_ORDER_UPDATE_BILLING_COUNTRY']
        },
        {
          'rebill_discount' => ENV['TEST_ORDER_UPDATE_REBILL_DISCOUNT'],
          'next_rebill_product' => ENV['TEST_ORDER_UPDATE_NEXT_REBILL_PRODUCT'],
          'cc_number' => ENV['TEST_ORDER_UPDATE_CC_NUMBER']
        },
        {
          'check_routing' => ENV['TEST_ORDER_UPDATE_CHECK_ROUTING'],
          'check_account' => ENV['TEST_ORDER_UPDATE_CHECK_ACCOUNT'],
          'check_ssn' => ENV['TEST_ORDER_UPDATE_CHECK_SSN']
        },
        {
          'cc_expiration_date' => ENV['TEST_ORDER_UPDATE_CC_EXPIRATION_DATE'],
          'cc_payment_type' => ENV['TEST_ORDER_UPDATE_CC_PAYMENT_TYPE']
        },
        {
          'recurring_date' => ENV['TEST_ORDER_UPDATE_RECURRING_DATE']
        },
        {
          'stop_recurring_next_success' => ENV['TEST_ORDER_UPDATE_STOP_RECURRING_NEXT_SUCCESS']
        },
        {
          'rma' => ENV['TEST_ORDER_UPDATE_RMA'],
          'return' => ENV['TEST_ORDER_UPDATE_RETURN']
        },
        {
          'tracking_number' => ENV['TEST_ORDER_UPDATE_TRACKING_NUMBER'],
          'payment_received' => ENV['TEST_ORDER_UPDATE_PAYMENT_RECEIVED'],
          'subscription_override' => ENV['TEST_ORDER_UPDATE_SUBSCRIPTION_OVERRIDE']
        },
        {
          'afid' => Faker::RickAndMorty.location,
          'affid' => Faker::RickAndMorty.location,
          'aid' => Faker::RickAndMorty.location
        },
        {
          'sid' => Faker::RickAndMorty.location,
          'c1' => Faker::RickAndMorty.location
        },
        {
          'c2' => Faker::RickAndMorty.location,
          'c3' => Faker::RickAndMorty.location,
          'opt' => Faker::RickAndMorty.location
        }
      ]

      response = lime_light.order_update({
        'sync_all' => ENV['TEST_ORDER_UPDATE_SYNC_ALL'],
        'order_id' => {
          ENV['TEST_ORDER_UPDATE_ORDER_ID_1'] => options.sample,
          ENV['TEST_ORDER_UPDATE_ORDER_ID_2'] => options.sample,
          ENV['TEST_ORDER_UPDATE_ORDER_ID_3'] => options.sample
        }
      })
      expect(response[:success]).to eq true
    end
  end
end